@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding= UTF-8
 #
-#	wbar configuration gui  v0.7.0
+#	wbar configuration gui  v0.7.2
 #
 #	Created by
 #		Mika Hynnä <mika.hynna@wippies.com>
@@ -14,37 +14,44 @@
 # Requires
 # * >=python-2.4
 # * >=pygtk-2.10
+# * >=gettext-0.16
 #
-from locale import getlocale
 
 # Read and replaced from wbar's configuration file comment '#wbarlaunchcommand=""
 #global wbarcommand
 wbarcommand = "wbar -bpress -above-desk"
-import os
-import sys
-import pygtk
-pygtk.require('2.0')
-import gtk
-import gobject
-import string
-import locale
 
-if gtk.pygtk_version < (2,3,90):
-	print "PyGtk 2.3.90 or later required"
-	raise SystemExit
+# "Hard coded" custom config file can be set in here:
+customwbarconfigfile = "/path/to/config"
+
+try:
+    import os
+    import sys
+    import pygtk
+    import gtk
+    import gobject
+    import string
+    import locale
+    from locale import getlocale
+except:
+    print("*** ERROR ***\n");
+    print("All required python dependencies were not found!\n")
+    print("Make sure that you have new enough python, pygtk, gobject and gettext installed!\n")
+    sys.exit()
 
 # Localization support using gettext
-import gettext
-if (os.path.exists("locale/")):
-	gettext.bindtextdomain('wbarconf', './locale/')
-gettext.textdomain('wbarconf')
-_ = gettext.gettext #_('')
+try:
+    import gettext
+    if (os.path.exists("locale/")):
+        gettext.bindtextdomain('wbarconf', './locale/')
+    gettext.textdomain('wbarconf')
+    _ = gettext.gettext #_('')
+except:
+    #def _(message):
+    print("Gettext error, defaulting to english!")
+    #    return message
 
-# xdg stuff
-import xdg
-
-
-wbarversion="0.7.0"
+wbarversion="0.7.2"
 
 ITEM_ID = 0
 ITEM_ICON = 1
@@ -61,6 +68,7 @@ PLACE_ICON=4
 DROP_TYPE_TREEVIEWROW=1
 DROP_TYPE_DESKTOP=0
 
+commandlinewbarconfigfile=""
 
 ## SettingsDialog class BEGINS
 class SettingsDialog:
@@ -91,7 +99,7 @@ class SettingsDialog:
 
         def removeProperty(self, property, hasparam=False):
                 global wbarcommand
-                print(wbarcommand)
+                #print(wbarcommand)
                 if (wbarcommand.find(property) != -1):
                     cmd = str(wbarcommand).split(' ')
                     wbarcommand=""
@@ -632,6 +640,8 @@ class SettingsDialog:
 
 def readconf():
         wbarcmd = "wbar -bpress -above-desk"
+        global commandlinewbarconfigfile
+        
 	lines=0
 	lastemptyline=0
 	items=list()
@@ -643,6 +653,12 @@ def readconf():
 	if (os.path.exists(userconf)):
 		print "User configuration file found: ~/.wbar"
 		conf = userconf
+        elif (os.path.exists(commandlinewbarconfigfile)):
+            print "Using config file set in command line: '"+commandlinewbarconfigfile+"'"
+            conf = commandlinewbarconfigfile
+        elif (os.path.exists(customwbarconfigfile)):
+            conf = customwbarconfigfile
+            print "Using custom wbar config file: '"+customwbarconfigfile+"'"
 	elif os.path.exists('/usr/share/wbar/dot.wbar'):
 		conf = '/usr/share/wbar/dot.wbar'
 		print "Shared configuration found: /usr/share/wbar/dot.wbar"
@@ -1140,10 +1156,14 @@ class WbarGui:
 		self.HBoxButtons.pack_start(self.statusbar, False, False)
 		
                 self.settingsdialog = SettingsDialog(self)
-        
 		#Show main window frame and all content
 		print "All inits ok so far, showing main window."
-		self.window.show_all()
+                self.window.show_all()
+                global commandlinewbarconfigfile
+                if (os.path.exists(commandlinewbarconfigfile)):
+                    print commandlinewbarconfigfile
+                    self.statusbar.set_text(_("Please, save settings now to have latest configuration."))
+                
 
 
 #################################################################
@@ -1233,14 +1253,10 @@ class WbarGui:
                 size = self.button_font_size.get_value_as_int()
                 self.configuration[0][ITEM_TITLE] = font+"/"+str(size)
                 if (os.path.exists(font)):
-                    style = self.text_font.get_style()
-                    style.text[gtk.STATE_NORMAL] =self.text_icon.get_colormap().alloc_color('black')
-                    self.text_font.set_style(style)
+                    self.text_font.modify_text(gtk.STATE_NORMAL, None)
                 else:
-                    style = self.text_font.get_style()
-                    style.text[gtk.STATE_NORMAL] =self.text_icon.get_colormap().alloc_color('red')
-                    self.text_font.set_style(style)
-                    
+                    self.text_font.modify_text(gtk.STATE_NORMAL, gtk.gdk.Color(50000,0,0,0))
+
 
 
 
@@ -1378,9 +1394,7 @@ class WbarGui:
 		image = gtk.Image()
 		model = self.treeview.get_model()
                 
-                style = self.text_icon.get_style()
-                style.text[gtk.STATE_NORMAL] =self.text_icon.get_colormap().alloc_color('black')
-                self.text_icon.set_style(style)
+                self.text_icon.modify_text(gtk.STATE_NORMAL, None)
 		try:
 			selection=self.treeview.get_cursor()[0][0]
 		except:
@@ -1402,9 +1416,8 @@ class WbarGui:
 			self.icon_image.set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_DIALOG)
 			model.set_value(model.get_iter(selection) , PLACE_IMAGE, None)
 			model.set_value(model.get_iter(selection), PLACE_ICON, iconfile)
-                        style = self.text_icon.get_style()
-                        style.text[gtk.STATE_NORMAL] =self.text_icon.get_colormap().alloc_color('red')
-                        self.text_icon.set_style(style)
+                        self.text_icon.modify_text(gtk.STATE_NORMAL, gtk.gdk.Color(50000,0,0,0))
+
 			
 
 
@@ -1456,13 +1469,9 @@ class WbarGui:
             background = str(n.get_text())
             self.configuration[0][ITEM_ICON] = background
             if (os.path.exists(background)):
-                style = self.text_bg.get_style()
-                style.text[gtk.STATE_NORMAL] =self.text_icon.get_colormap().alloc_color('black')
-                self.text_bg.set_style(style)
+                self.text_bg.modify_text(gtk.STATE_NORMAL, None)
             else:
-                style = self.text_bg.get_style()
-                style.text[gtk.STATE_NORMAL] =self.text_icon.get_colormap().alloc_color('red')
-                self.text_bg.set_style(style)
+                self.text_bg.modify_text(gtk.STATE_NORMAL, gtk.gdk.Color(50000,0,0,0))
 
 
 	def text_font_change(self, n):
@@ -1723,17 +1732,29 @@ class WbarGui:
 
 if __name__ == "__main__":
 	# Command line params:
-	try:
-		if (len(sys.argv) > 1):
-			if (sys.argv[1] == "--wbar"):
-				conf, wbarcmd = readconf()
-				# Launch wbar with params and quit:
-				print("Executing: "+str(wbarcmd))
-				os.system("nohup "+wbarcmd+" &")
-				print("Exiting...")
-				exit()
-	except TypeError:
-		print("Unexpected error, trying to continue...")
+        ccmd = 1
+        #exit after commandlines
+        startwbar=False
+        startwbarandexit=False
+        #print "Argc :"+str(len(sys.argv))
+        for arg in sys.argv:
+            #print arg
+            try:
+                if (arg == "--wbar"):
+                    startwbar=True
+                if (arg == "--config"):
+                    commandlinewbarconfigfile = sys.argv[ccmd]
+                    print "Found command line configuration file '"+commandlinewbarconfigfile+"', will be used if ~/.wbar does not exists."
+            except TypeError:
+                print("Unexpected error, trying to continue...")
+            ccmd+=1
+        if (startwbar):
+            conf, wbarcmd = readconf()
+            # Launch wbar with params and quit:
+            print("Executing: "+str(wbarcmd))
+            os.system("nohup "+wbarcmd+" &")
+            print("Exiting...")
+            exit()
 	# The prog:
 	print "wbar configuration gui, v"+str(wbarversion)
 	print "Copyright 2008 Mika Hynnä <mika.hynna@wippies.com>"
